Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/edwh_restic_plugin/__about__.py | 1 | 1 | 0 | 0%
src/edwh_restic_plugin/__init__.py | 0 | 0 | 0 | 100%
src/edwh_restic_plugin/env.py | 64 | 54 | 0 | 16%
src/edwh_restic_plugin/forget.py | 130 | 17 | 0 | 87%
src/edwh_restic_plugin/helpers.py | 20 | 11 | 0 | 45%
src/edwh_restic_plugin/repositories/__init__.py | 234 | 119 | 0 | 49%
src/edwh_restic_plugin/repositories/b2.py | 35 | 25 | 0 | 29%
src/edwh_restic_plugin/repositories/local.py | 24 | 13 | 0 | 46%
src/edwh_restic_plugin/repositories/oracle.py | 24 | 13 | 0 | 46%
src/edwh_restic_plugin/repositories/r2.py | 23 | 12 | 0 | 48%
src/edwh_restic_plugin/repositories/s3.py | 24 | 14 | 0 | 42%
src/edwh_restic_plugin/repositories/sftp.py | 30 | 21 | 0 | 30%
src/edwh_restic_plugin/repositories/swift.py | 39 | 29 | 0 | 26%
src/edwh_restic_plugin/restictypes.py | 188 | 188 | 0 | 0%
src/edwh_restic_plugin/tasks.py | 82 | 82 | 0 | 0%
Total | 918 | 599 | 0 | 35%

No items found using the specified filter.